==> moserial-2.27.4.tar.bz2: moserial-2.27.4/src/XmodemFilenameDialog.c <==

#include <src/XmodemFilenameDialog.h>




struct _moserialXmodemFilenameDialogPrivate {
	GtkBuilder* _builder;
	GtkDialog* dialog;
	GtkEntry* xmodemFilename;
};

#define MOSERIAL_XMODEM_FILENAME_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MOSERIAL_TYPE_XMODEM_FILENAME_DIALOG, moserialXmodemFilenameDialogPrivate))
enum  {
	MOSERIAL_XMODEM_FILENAME_DIALOG_DUMMY_PROPERTY,
	MOSERIAL_XMODEM_FILENAME_DIALOG_BUILDER
};
static void moserial_xmodem_filename_dialog_response (moserialXmodemFilenameDialog* self, GtkWidget* w, gint r);
static void moserial_xmodem_filename_dialog_set_builder (moserialXmodemFilenameDialog* self, GtkBuilder* value);
static gboolean _moserial_xmodem_filename_dialog_hide_gtk_widget_delete_event (GtkDialog* _sender, const GdkEvent* event, gpointer self);
static void _moserial_xmodem_filename_dialog_response_gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static GObject * moserial_xmodem_filename_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer moserial_xmodem_filename_dialog_parent_class = NULL;
static void moserial_xmodem_filename_dialog_finalize (GObject* obj);
static int _vala_strcmp0 (const char * str1, const char * str2);



moserialXmodemFilenameDialog* moserial_xmodem_filename_dialog_construct (GType object_type, GtkBuilder* builder) {
	GParameter * __params;
	GParameter * __params_it;
	moserialXmodemFilenameDialog * self;
	g_return_val_if_fail (builder != NULL, NULL);
	__params = g_new0 (GParameter, 1);
	__params_it = __params;
	__params_it->name = "builder";
	g_value_init (&__params_it->value, GTK_TYPE_BUILDER);
	g_value_set_object (&__params_it->value, builder);
	__params_it++;
	self = g_object_newv (object_type, __params_it - __params, __params);
	while (__params_it > __params) {
		--__params_it;
		g_value_unset (&__params_it->value);
	}
	g_free (__params);
	return self;
}


moserialXmodemFilenameDialog* moserial_xmodem_filename_dialog_new (GtkBuilder* builder) {
	return moserial_xmodem_filename_dialog_construct (MOSERIAL_TYPE_XMODEM_FILENAME_DIALOG, builder);
}


void moserial_xmodem_filename_dialog_show (moserialXmodemFilenameDialog* self) {
	g_return_if_fail (self != NULL);
	gtk_dialog_run (self->priv->dialog);
}


gboolean moserial_xmodem_filename_dialog_hide (moserialXmodemFilenameDialog* self, GtkWidget* w) {
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (w != NULL, FALSE);
	gtk_widget_hide ((GtkWidget*) self->priv->dialog);
	return TRUE;
}


static void moserial_xmodem_filename_dialog_response (moserialXmodemFilenameDialog* self, GtkWidget* w, gint r) {
	char* _tmp1;
	const char* _tmp0;
	g_return_if_fail (self != NULL);
	g_return_if_fail (w != NULL);
	_tmp1 = NULL;
	_tmp0 = NULL;
	self->filename = (_tmp1 = (_tmp0 = gtk_entry_get_text (self->priv->xmodemFilename), (_tmp0 == NULL) ? NULL : g_strdup (_tmp0)), self->filename = (g_free (self->filename), NULL), _tmp1);
	moserial_xmodem_filename_dialog_hide (self, w);
	if (_vala_strcmp0 (self->filename, "") == 0) {
		char* _tmp2;
		_tmp2 = NULL;
		self->filename = (_tmp2 = g_strdup ("xmodem.file"), self->filename = (g_free (self->filename), NULL), _tmp2);
	}
}


GtkBuilder* moserial_xmodem_filename_dialog_get_builder (moserialXmodemFilenameDialog* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return self->priv->_builder;
}


static void moserial_xmodem_filename_dialog_set_builder (moserialXmodemFilenameDialog* self, GtkBuilder* value) {
	GtkBuilder* _tmp2;
	GtkBuilder* _tmp1;
	g_return_if_fail (self != NULL);
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_builder = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_builder == NULL) ? NULL : (self->priv->_builder = (g_object_unref (self->priv->_builder), NULL)), _tmp2);
	g_object_notify ((GObject *) self, "builder");
}


static gboolean _moserial_xmodem_filename_dialog_hide_gtk_widget_delete_event (GtkDialog* _sender, const GdkEvent* event, gpointer self) {
	return moserial_xmodem_filename_dialog_hide (self, _sender);
}


static void _moserial_xmodem_filename_dialog_response_gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
	moserial_xmodem_filename_dialog_response (self, _sender, response_id);
}


static GObject * moserial_xmodem_filename_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	moserialXmodemFilenameDialogClass * klass;
	GObjectClass * parent_class;
	moserialXmodemFilenameDialog * self;
	klass = MOSERIAL_XMODEM_FILENAME_DIALOG_CLASS (g_type_class_peek (MOSERIAL_TYPE_XMODEM_FILENAME_DIALOG));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = MOSERIAL_XMODEM_FILENAME_DIALOG (obj);
	{
		GtkDialog* _tmp1;
		GtkDialog* _tmp0;
		GtkEntry* _tmp3;
		GtkEntry* _tmp2;
		_tmp1 = NULL;
		_tmp0 = NULL;
		self->priv->dialog = (_tmp1 = (_tmp0 = GTK_DIALOG (gtk_builder_get_object (self->priv->_builder, "xmodem_filename_dialog")), (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->dialog == NULL) ? NULL : (self->priv->dialog = (g_object_unref (self->priv->dialog), NULL)), _tmp1);
		_tmp3 = NULL;
		_tmp2 = NULL;
		self->priv->xmodemFilename = (_tmp3 = (_tmp2 = GTK_ENTRY (gtk_builder_get_object (self->priv->_builder, "xmodem_filename")), (_tmp2 == NULL) ? NULL : g_object_ref (_tmp2)), (self->priv->xmodemFilename == NULL) ? NULL : (self->priv->xmodemFilename = (g_object_unref (self->priv->xmodemFilename), NULL)), _tmp3);
		g_signal_connect_object ((GtkWidget*) self->priv->dialog, "delete-event", (GCallback) _moserial_xmodem_filename_dialog_hide_gtk_widget_delete_event, self, 0);
		g_signal_connect_object (self->priv->dialog, "response", (GCallback) _moserial_xmodem_filename_dialog_response_gtk_dialog_response, self, 0);
	}
	return obj;
}


static void moserial_xmodem_filename_dialog_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	moserialXmodemFilenameDialog * self;
	gpointer boxed;
	self = MOSERIAL_XMODEM_FILENAME_DIALOG (object);
	switch (property_id) {
		case MOSERIAL_XMODEM_FILENAME_DIALOG_BUILDER:
		g_value_set_object (value, moserial_xmodem_filename_dialog_get_builder (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void moserial_xmodem_filename_dialog_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	moserialXmodemFilenameDialog * self;
	self = MOSERIAL_XMODEM_FILENAME_DIALOG (object);
	switch (property_id) {
		case MOSERIAL_XMODEM_FILENAME_DIALOG_BUILDER:
		moserial_xmodem_filename_dialog_set_builder (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void moserial_xmodem_filename_dialog_class_init (moserialXmodemFilenameDialogClass * klass) {
	moserial_xmodem_filename_dialog_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (moserialXmodemFilenameDialogPrivate));
	G_OBJECT_CLASS (klass)->get_property = moserial_xmodem_filename_dialog_get_property;
	G_OBJECT_CLASS (klass)->set_property = moserial_xmodem_filename_dialog_set_property;
	G_OBJECT_CLASS (klass)->constructor = moserial_xmodem_filename_dialog_constructor;
	G_OBJECT_CLASS (klass)->finalize = moserial_xmodem_filename_dialog_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), MOSERIAL_XMODEM_FILENAME_DIALOG_BUILDER, g_param_spec_object ("builder", "builder", "builder", GTK_TYPE_BUILDER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
}


static void moserial_xmodem_filename_dialog_instance_init (moserialXmodemFilenameDialog * self) {
	self->priv = MOSERIAL_XMODEM_FILENAME_DIALOG_GET_PRIVATE (self);
}


static void moserial_xmodem_filename_dialog_finalize (GObject* obj) {
	moserialXmodemFilenameDialog * self;
	self = MOSERIAL_XMODEM_FILENAME_DIALOG (obj);
	(self->priv->_builder == NULL) ? NULL : (self->priv->_builder = (g_object_unref (self->priv->_builder), NULL));
	(self->priv->dialog == NULL) ? NULL : (self->priv->dialog = (g_object_unref (self->priv->dialog), NULL));
	(self->priv->xmodemFilename == NULL) ? NULL : (self->priv->xmodemFilename = (g_object_unref (self->priv->xmodemFilename), NULL));
	self->filename = (g_free (self->filename), NULL);
	G_OBJECT_CLASS (moserial_xmodem_filename_dialog_parent_class)->finalize (obj);
}


GType moserial_xmodem_filename_dialog_get_type (void) {
	static GType moserial_xmodem_filename_dialog_type_id = 0;
	if (moserial_xmodem_filename_dialog_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (moserialXmodemFilenameDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) moserial_xmodem_filename_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (moserialXmodemFilenameDialog), 0, (GInstanceInitFunc) moserial_xmodem_filename_dialog_instance_init, NULL };
		moserial_xmodem_filename_dialog_type_id = g_type_register_static (G_TYPE_OBJECT, "moserialXmodemFilenameDialog", &g_define_type_info, 0);
	}
	return moserial_xmodem_filename_dialog_type_id;
}


static int _vala_strcmp0 (const char * str1, const char * str2) {
	if (str1 == NULL) {
		return -(str1 != str2);
	}
	if (str2 == NULL) {
		return str1 != str2;
	}
	return strcmp (str1, str2);
}

==> moserial-2.27.5.tar.bz2: moserial-2.27.5/src/XmodemFilenameDialog.c <==

#include <src/XmodemFilenameDialog.h>




struct _moserialXmodemFilenameDialogPrivate {
	GtkBuilder* _builder;
	GtkDialog* dialog;
	GtkEntry* xmodemFilename;
};

#define MOSERIAL_XMODEM_FILENAME_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MOSERIAL_TYPE_XMODEM_FILENAME_DIALOG, moserialXmodemFilenameDialogPrivate))
enum  {
	MOSERIAL_XMODEM_FILENAME_DIALOG_DUMMY_PROPERTY,
	MOSERIAL_XMODEM_FILENAME_DIALOG_BUILDER
};
static void moserial_xmodem_filename_dialog_response (moserialXmodemFilenameDialog* self, GtkWidget* w, gint r);
static void moserial_xmodem_filename_dialog_set_builder (moserialXmodemFilenameDialog* self, GtkBuilder* value);
static gboolean _moserial_xmodem_filename_dialog_hide_gtk_widget_delete_event (GtkDialog* _sender, const GdkEvent* event, gpointer self);
static void _moserial_xmodem_filename_dialog_response_gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static GObject * moserial_xmodem_filename_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static gpointer moserial_xmodem_filename_dialog_parent_class = NULL;
static void moserial_xmodem_filename_dialog_finalize (GObject* obj);
static int _vala_strcmp0 (const char * str1, const char * str2);



moserialXmodemFilenameDialog* moserial_xmodem_filename_dialog_construct (GType object_type, GtkBuilder* builder) {
	GParameter * __params;
	GParameter * __params_it;
	moserialXmodemFilenameDialog * self;
	g_return_val_if_fail (builder != NULL, NULL);
	__params = g_new0 (GParameter, 1);
	__params_it = __params;
	__params_it->name = "builder";
	g_value_init (&__params_it->value, GTK_TYPE_BUILDER);
	g_value_set_object (&__params_it->value, builder);
	__params_it++;
	self = g_object_newv (object_type, __params_it - __params, __params);
	while (__params_it > __params) {
		--__params_it;
		g_value_unset (&__params_it->value);
	}
	g_free (__params);
	return self;
}


moserialXmodemFilenameDialog* moserial_xmodem_filename_dialog_new (GtkBuilder* builder) {
	return moserial_xmodem_filename_dialog_construct (MOSERIAL_TYPE_XMODEM_FILENAME_DIALOG, builder);
}


void moserial_xmodem_filename_dialog_show (moserialXmodemFilenameDialog* self) {
	g_return_if_fail (self != NULL);
	gtk_dialog_run (self->priv->dialog);
}


gboolean moserial_xmodem_filename_dialog_hide (moserialXmodemFilenameDialog* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	gtk_widget_hide ((GtkWidget*) self->priv->dialog);
	return TRUE;
}


static void moserial_xmodem_filename_dialog_response (moserialXmodemFilenameDialog* self, GtkWidget* w, gint r) {
	char* _tmp1;
	const char* _tmp0;
	g_return_if_fail (self != NULL);
	g_return_if_fail (w != NULL);
	_tmp1 = NULL;
	_tmp0 = NULL;
	self->filename = (_tmp1 = (_tmp0 = gtk_entry_get_text (self->priv->xmodemFilename), (_tmp0 == NULL) ? NULL : g_strdup (_tmp0)), self->filename = (g_free (self->filename), NULL), _tmp1);
	moserial_xmodem_filename_dialog_hide (self);
	if (_vala_strcmp0 (self->filename, "") == 0) {
		char* _tmp2;
		_tmp2 = NULL;
		self->filename = (_tmp2 = g_strdup ("xmodem.file"), self->filename = (g_free (self->filename), NULL), _tmp2);
	}
}


GtkBuilder* moserial_xmodem_filename_dialog_get_builder (moserialXmodemFilenameDialog* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return self->priv->_builder;
}


static void moserial_xmodem_filename_dialog_set_builder (moserialXmodemFilenameDialog* self, GtkBuilder* value) {
	GtkBuilder* _tmp2;
	GtkBuilder* _tmp1;
	g_return_if_fail (self != NULL);
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_builder = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_object_ref (_tmp1)), (self->priv->_builder == NULL) ? NULL : (self->priv->_builder = (g_object_unref (self->priv->_builder), NULL)), _tmp2);
	g_object_notify ((GObject *) self, "builder");
}


static gboolean _moserial_xmodem_filename_dialog_hide_gtk_widget_delete_event (GtkDialog* _sender, const GdkEvent* event, gpointer self) {
	return moserial_xmodem_filename_dialog_hide (self);
}


static void _moserial_xmodem_filename_dialog_response_gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
	moserial_xmodem_filename_dialog_response (self, _sender, response_id);
}


static GObject * moserial_xmodem_filename_dialog_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	moserialXmodemFilenameDialogClass * klass;
	GObjectClass * parent_class;
	moserialXmodemFilenameDialog * self;
	klass = MOSERIAL_XMODEM_FILENAME_DIALOG_CLASS (g_type_class_peek (MOSERIAL_TYPE_XMODEM_FILENAME_DIALOG));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = MOSERIAL_XMODEM_FILENAME_DIALOG (obj);
	{
		GtkDialog* _tmp1;
		GtkDialog* _tmp0;
		GtkEntry* _tmp3;
		GtkEntry* _tmp2;
		_tmp1 = NULL;
		_tmp0 = NULL;
		self->priv->dialog = (_tmp1 = (_tmp0 = GTK_DIALOG (gtk_builder_get_object (self->priv->_builder, "xmodem_filename_dialog")), (_tmp0 == NULL) ? NULL : g_object_ref (_tmp0)), (self->priv->dialog == NULL) ? NULL : (self->priv->dialog = (g_object_unref (self->priv->dialog), NULL)), _tmp1);
		_tmp3 = NULL;
		_tmp2 = NULL;
		self->priv->xmodemFilename = (_tmp3 = (_tmp2 = GTK_ENTRY (gtk_builder_get_object (self->priv->_builder, "xmodem_filename")), (_tmp2 == NULL) ? NULL : g_object_ref (_tmp2)), (self->priv->xmodemFilename == NULL) ? NULL : (self->priv->xmodemFilename = (g_object_unref (self->priv->xmodemFilename), NULL)), _tmp3);
		g_signal_connect_object ((GtkWidget*) self->priv->dialog, "delete-event", (GCallback) _moserial_xmodem_filename_dialog_hide_gtk_widget_delete_event, self, 0);
		g_signal_connect_object (self->priv->dialog, "response", (GCallback) _moserial_xmodem_filename_dialog_response_gtk_dialog_response, self, 0);
	}
	return obj;
}


static void moserial_xmodem_filename_dialog_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	moserialXmodemFilenameDialog * self;
	gpointer boxed;
	self = MOSERIAL_XMODEM_FILENAME_DIALOG (object);
	switch (property_id) {
		case MOSERIAL_XMODEM_FILENAME_DIALOG_BUILDER:
		g_value_set_object (value, moserial_xmodem_filename_dialog_get_builder (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void moserial_xmodem_filename_dialog_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	moserialXmodemFilenameDialog * self;
	self = MOSERIAL_XMODEM_FILENAME_DIALOG (object);
	switch (property_id) {
		case MOSERIAL_XMODEM_FILENAME_DIALOG_BUILDER:
		moserial_xmodem_filename_dialog_set_builder (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void moserial_xmodem_filename_dialog_class_init (moserialXmodemFilenameDialogClass * klass) {
	moserial_xmodem_filename_dialog_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (moserialXmodemFilenameDialogPrivate));
	G_OBJECT_CLASS (klass)->get_property = moserial_xmodem_filename_dialog_get_property;
	G_OBJECT_CLASS (klass)->set_property = moserial_xmodem_filename_dialog_set_property;
	G_OBJECT_CLASS (klass)->constructor = moserial_xmodem_filename_dialog_constructor;
	G_OBJECT_CLASS (klass)->finalize = moserial_xmodem_filename_dialog_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), MOSERIAL_XMODEM_FILENAME_DIALOG_BUILDER, g_param_spec_object ("builder", "builder", "builder", GTK_TYPE_BUILDER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
}


static void moserial_xmodem_filename_dialog_instance_init (moserialXmodemFilenameDialog * self) {
	self->priv = MOSERIAL_XMODEM_FILENAME_DIALOG_GET_PRIVATE (self);
}


static void moserial_xmodem_filename_dialog_finalize (GObject* obj) {
	moserialXmodemFilenameDialog * self;
	self = MOSERIAL_XMODEM_FILENAME_DIALOG (obj);
	(self->priv->_builder == NULL) ? NULL : (self->priv->_builder = (g_object_unref (self->priv->_builder), NULL));
	(self->priv->dialog == NULL) ? NULL : (self->priv->dialog = (g_object_unref (self->priv->dialog), NULL));
	(self->priv->xmodemFilename == NULL) ? NULL : (self->priv->xmodemFilename = (g_object_unref (self->priv->xmodemFilename), NULL));
	self->filename = (g_free (self->filename), NULL);
	G_OBJECT_CLASS (moserial_xmodem_filename_dialog_parent_class)->finalize (obj);
}


GType moserial_xmodem_filename_dialog_get_type (void) {
	static GType moserial_xmodem_filename_dialog_type_id = 0;
	if (moserial_xmodem_filename_dialog_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (moserialXmodemFilenameDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) moserial_xmodem_filename_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (moserialXmodemFilenameDialog), 0, (GInstanceInitFunc) moserial_xmodem_filename_dialog_instance_init, NULL };
		moserial_xmodem_filename_dialog_type_id = g_type_register_static (G_TYPE_OBJECT, "moserialXmodemFilenameDialog", &g_define_type_info, 0);
	}
	return moserial_xmodem_filename_dialog_type_id;
}


static int _vala_strcmp0 (const char * str1, const char * str2) {
	if (str1 == NULL) {
		return -(str1 != str2);
	}
	if (str2 == NULL) {
		return str1 != str2;
	}
	return strcmp (str1, str2);
}
